function run_data = ...
    find_TDP_from_res(run_data, run_folder, res_filename)
%THIS FUNCTION FINDS IMPORTANT PARAMETERS FROM THE STAMOD.RES FILE. THE
%IMPORTANT PARAMTERS ARE:
%
%   1. TOUCH DOWN POINT
%   2. STATIC CONFIG OF THE RISER
%
%Name: Emir Lejlic.
%Date: 10.05.13
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Creating a waitbar
h = waitbar(0,'Finding important paramters from stamod.res file...');

    for i = 1:length(run_data)
        
        waitbar(i / length(run_data))
        
        %------------------------------------------------------------------
        %SEARCHING FOR THE TDP IN THE STAMOD.RES FILE.
        %------------------------------------------------------------------
       
        %The folder where the stamod.res file is.
        res_file_path = fullfile(run_folder,run_data(i,1).name,res_filename);
        %Going to the folder.
                
        %Reading the .res file containing the TDPs.
        stamod_res_text = file2str(res_file_path);
        
        %Finding the Seafloor spring / friction status in the text
        str_seafloor = strfind(stamod_res_text,'Seafloor spring / friction status');
        
        %This is the string after the 
        str_you_may = strfind(stamod_res_text,'You may');
        
        %This is now the only 
        seafloor_spring_text = stamod_res_text(str_seafloor:str_you_may-1);
        
        %Finding the last (-) in the text. It is possible to find the TDP
        %element after that.        
        str_L = strfind(seafloor_spring_text,'(L)');
        
        %Extracting the element no.
        element_no = seafloor_spring_text(str_L(end)+13:str_L(end)+16);
        
        %Adding the TDP and its respective x value point on the riser element to the struct.
        run_data(i,1).TDP_element = str2double(element_no);
        run_data(i,1).TDP_x_value = run_data(i,1).fatigue_damage(str2double(element_no),1);     
                
        %------------------------------------------------------------------
        %SEARCHING FOR THE STATIC CONFIG IN THE STAMOD.RES FILE.
        %------------------------------------------------------------------        
        
        %Finding the X-coord. in the text.
        str_xcoord = strfind(stamod_res_text,'X-coord.');
        
        %This is the string after the the static results.
        str_static_results = strfind(stamod_res_text,'STATIC RESULTS WRITTEN TO FILE');
        
        %This is the important text.
        config_text_tmp = stamod_res_text(str_xcoord:str_static_results-1);
        
        %Finding 'number' in the text.
        str_number = strfind(config_text_tmp,'number');
        
        %The config results are now.
        config_text = config_text_tmp(str_number+length('number')+1:end);
        
        %Making the text into an array with the results.
        %Under it is possible to see the headers.
        %| Node | X-coord. | Y-coord. | Z-coord. | Y-moment | Y-curv. | Z-curv. |
        run_data(i,1).static_config = str2num(config_text);
        
    end
    
    close(h)     
    
    
end

