%% Run sum_fatigue_damage() function...
clc;
clear all;
close all;

copy_to_folder = 'C:\Users\Emir Lejlic\Dropbox\Masteroppgave\Master_report\figures\showing_the_xy_summation';

run_folder = 'C:\Users\Emir Lejlic\Documents\MATLAB\master_thesis\fatigue_damage_xy_variation\showing_the_procedure';

%Creating a struct with the important info:
run_data = save_run_xy_info_in_struct(run_folder);

%% Adding the fatigue damage to the run_data struct.
fatigue_file = 'fatigue_damage.txt';
run_data = add_fatigue_damage_to_struct(run_data, run_folder,fatigue_file);


%% Summing the fatigue

[final_fat_dam, sum_prob] = sum_fatigue_damage_from_xy_variation(run_data);

fprintf('Summed p(x,y): %6.3f %%.\n',sum_prob *100);

%% Some key values for fatigue processing.

%Origin: original analysis with RHoP at (0,0)
%Variation: varying the (x,y) of the RHoP.
clc;
fat_max_origin = max(run_data(1,1).fatigue_damage(:,2));
indx_origin = find(run_data(1,1).fatigue_damage(:,2) == fat_max_origin);
fat_max_variation = max(final_fat_dam(:,2));
indx_variation = find(final_fat_dam(:,2) == fat_max_variation);

format shortg
x_max_origin = run_data(1,1).fatigue_damage(indx_origin,1);
x_max_variation = final_fat_dam(indx_variation,1);
format short

%This is the difference of max fat. x-value...
dx = abs(x_max_origin-x_max_variation);

    %If the difference is small, I set dx = 3. Look at the xlim in the figures.
    if dx < 3

        dx = 3;

    end
    
%% Finding important parameters from the stamod.res file

%From the stamod.res file:
res_filename = 'sima_stamod.res';
run_data = find_important_parameters_resfile(run_data, run_folder, res_filename);


%% Finding the interval of the TDP 
TDP_x_values = zeros(1,length(run_data));
Prob_values = zeros(1,length(run_data));
for i = 1:length(run_data)
   
    TDP_x_values(i) = run_data(i,1).TDP_x_value;
    Prob_values(i) = run_data(i,1).prob;
    
end

min_TDP = min(TDP_x_values);
max_TDP = max(TDP_x_values);

plot_TDP_y = 0.15;
plot_TDP = [min_TDP plot_TDP_y; max_TDP plot_TDP_y];

%% Comparing the axial force of the riser...
close all;

%The axial matrix has one row less than the static config matrix.
axial_rows = size(run_data(1,1).axial_force,1);

%Preallocating memory.
axial_force_origin = zeros(axial_rows,2);
axial_force_variation = zeros(axial_rows,2);
axial_force_variation_tmp = zeros(axial_rows,1);

%The line length [m]. OBS: 1:end-1 because of one less row!!
axial_force_variation(:,1) = run_data(1,1).fatigue_damage(1:end-1,1);
axial_force_origin(:,1) = axial_force_variation(:,1);

%Important that the first row is (0,0).
axial_force_origin(:,2) = run_data(1,1).axial_force(:,2);

%Adding together all the axial forces with their respective probabilities.
for i = 1:length(run_data)
   
   prob = run_data(i,1).prob;
   axial_force_variation_tmp = prob .* run_data(i,1).axial_force(:,2);
   
   axial_force_variation(:,2) = axial_force_variation(:,2) + axial_force_variation_tmp(:,1);
    
    
end

%Calculating the deviation between the axial forces.
deviation = zeros(1,axial_rows);

for i = 1:axial_rows      
     deviation(i)  = abs(axial_force_origin(i,2)-axial_force_variation(i,2));
end

%Max deviation.
max_dev = max(deviation);
   
%Plotting them to see the difference
figure()
plot(axial_force_variation(:,1),axial_force_variation(:,2),'-.b');
hold on;
plot(axial_force_origin(:,1),axial_force_origin(:,2),'--r');
title(['Max deviation between the axial forces: ',num2str(max_dev),' [kN]'])
xlabel('Riser length [m]');
ylabel('Effective tension [kN]');
legend('Original analysis','Variation of (x,y) analysis','Location','Best');

%This is the way I can create my figures
name = 'comparing_axial_tension';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

%% Plotting each fatigue damage multyplied with its probability and the final fatigue.
close all;
clc;
%The colormap.
cc = lines(length(run_data)+1);

legend_info = cell(1,length(run_data)+1);


figure()
hold on;
for i = 1:length(run_data)   
  
    leg_tmp = [' (',num2str(run_data(i,1).xpos),',',num2str(run_data(i,1).ypos),')'];
    legend_info{i} = strcat('RHoP',leg_tmp);
    
    clear x y;
    x = run_data(i,1).fatigue_damage(:,1);
    y = run_data(i,1).fatigue_damage(:,2).*run_data(i,1).prob;
    
    plot(x,y,'Color',cc(i,:));
    
    
end

legend_info{length(run_data)+1} = 'Final result';

hold on;
plot(final_fat_dam(:,1),final_fat_dam(:,2),'Color','k','LineWidth',1.5,'LineStyle','--');
xlim([1500 1750]);
legend(legend_info,'Location','NorthWest');

%This is the way I can create my figures
name = 'explanation_of_sum_fatigue';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

%% The plot
figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2),'b')
xlim([0 1800]);
hold on;
grid on;
plot(final_fat_dam(:,1),final_fat_dam(:,2),'r');
hold on;
grid on;
scatter(x_max_origin,fat_max_origin,40,[1 0 1],'fill','o')
hold on;
grid on;
scatter(x_max_variation,fat_max_variation,40,[0 0.8 0],'fill','o')
xlabel('Arclength [m]');
ylabel('Fatigue [1/year]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100),' %',]);
legend('Original analysis','Analysis with (x,y) variation',...
['Fat. = ',num2str(fat_max_origin),' [1/years]',' at x = ',num2str(x_max_origin),...
' m'],['Fat. = ',num2str(fat_max_variation),' [1/years]',' at x = ',num2str(x_max_variation),' m']...
,'Location','Best');

%This is the way I can create my figures
name = 'fatigue_damage_vs_variation_whole';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2),'b')
xlim([((x_max_variation+x_max_origin)/2)-(3*dx) 1750]);
ylim([0 fat_max_origin*1.5]);
hold on;
grid on;
plot(final_fat_dam(:,1),final_fat_dam(:,2),'r');
hold on;
grid on;
scatter(x_max_origin,fat_max_origin,40,[1 0 1],'fill','o')
hold on;
grid on;
scatter(x_max_variation,fat_max_variation,40,[0 0.8 0],'fill','o')
xlabel('Arclength [m]');
ylabel('Fatigue [1/year]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100),' %',]);
legend('Original analysis','Analysis with (x,y) variation',...
['Fat. = ',num2str(fat_max_origin),' [1/years]',' at x = ',num2str(x_max_origin),...
' m'],['Fat. = ',num2str(fat_max_variation),' [1/years]',' at x = ',num2str(x_max_variation),' m']...
,'Location','Best');

%This is the way I can create my figures
name = 'fatigue_damage_vs_variation_closeup';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;


figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2)./fat_max_origin,'b')
xlim([0 1800]);
hold on;
grid on;
plot(final_fat_dam(:,1),final_fat_dam(:,2)./fat_max_origin,'r');
hold on;
grid on;
scatter(x_max_origin,fat_max_origin./fat_max_origin,40,[1 0 1],'fill','o')
hold on;
grid on;
scatter(x_max_variation,fat_max_variation./fat_max_origin,40,[0 0.8 0],'fill','o')
xlabel('Arclength [m]');
ylabel('Normalized fatigue [-]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100),' %',]);
legend('Original analysis','Analysis with (x,y) variation',...
['Fat. = ',num2str(fat_max_origin),' [1/years]',' at x = ',num2str(x_max_origin),...
' m'],['Fat. = ',num2str(fat_max_variation),' [1/years]',' at x = ',num2str(x_max_variation),' m']...
,'Location','Best');

%This is the way I can create my figures
name = 'norm_fatigue_damage_vs_variation_whole';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;
%%

figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2)./fat_max_origin,'b')
xlim([((x_max_variation+x_max_origin)/2)-(3*dx) 1750]);
ylim([0 (fat_max_origin/fat_max_origin)*1.5]);
% hold on;
% grid on;
% plot(final_fat_dam(:,1),final_fat_dam(:,2)./fat_max_origin,'r');
% hold on;
% grid on;
% scatter(x_max_origin,fat_max_origin./fat_max_origin,40,[1 0 1],'fill','o')
% hold on;
% grid on;
% scatter(x_max_variation,fat_max_variation./fat_max_origin,40,[0 0.8 0],'fill','o')
hold on;
grid on;
%REMEMBER TO CHANGE THIS RIGHT HERE!!!!!
plot(TDP_x_values(1),Prob_values(1)/50,'ms','LineWidth',2,...
                'MarkerEdgeColor','k',...
                'MarkerFaceColor',[1 0.5 0],...
                'MarkerSize',5);
set(gca,'YTick',0:0.1:(fat_max_origin/fat_max_origin)*1.5)
xlabel('Arclength [m]');
ylabel('Normalized fatigue [-]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100),' %',]);
legend('Original analysis','Analysis with (x,y) variation',...
['Fat. = ',num2str(fat_max_origin),' [1/years]',' at x = ',num2str(x_max_origin),...
' m'],['Fat. = ',num2str(fat_max_variation),' [1/years]',' at x = ',num2str(x_max_variation),' m']...
,'Location','Best');

%%

%This is the way I can create my figures
name = 'norm_fatigue_damage_vs_variation_close';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;
%% Plotting the static config at a certian starting points
run = [1 2 3];

%Preallocating memory...
x_tdp = zeros(1,length(run));
z_tdp = zeros(1,length(run));
x_top = x_tdp;
y_top = x_top;

%Colormap: HSV. There are several to choose from.
c_hsv = lines(length(run));
c_jet = jet(length(run));

figure()

for i = 1:length(run)
    
    run_row = run(i);
    
    x_top(i) = run_data(run_row,1).xpos;
    y_top(i) = run_data(run_row,1).ypos;

    x_config = run_data(run_row,1).static_config(:,2);
    z_config = run_data(run_row,1).static_config(:,4);

    tdp_elem = run_data(run_row,1).TDP_element;
    x_tdp(i) = run_data(run_row,1).static_config(tdp_elem,2);
    z_tdp(i) = run_data(run_row,1).static_config(tdp_elem,4);

    hold on;
    plot(x_config,z_config,'Color',c_hsv(i,:));
    hold on;    
    scatter(x_tdp(i),z_tdp(i),40,'MarkerFaceColor',c_hsv(i,:),'MarkerEdgeColor','none');
    
end

x_avg = sum(x_tdp)/length(run);

grid on;
xlim([x_avg-50 x_avg+50]);
title('Static config. of the riser at different RHoP (x,y)')
xlabel('x [m]');
ylabel('z-axis / Water depth [m]');
legend(['Riser hang off coordinate (x,y): (',num2str(x_top(1)),',',num2str(y_top(1)),')'],...
    'TDP',['Riser hang off coordinate (x,y): (',num2str(x_top(2)),',',num2str(y_top(2)),')'],...
    'TDP',['Riser hang off coordinate (x,y): (',num2str(x_top(3)),',',num2str(y_top(3)),')'],'TDP')

%This is the way I can create my figures
name = 'TDP_variation_example';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

%%

xmin = 1200;
xmax = 1750;

figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2)./fat_max_origin,'b')
xlim([xmin xmax]);
ylim([0 (fat_max_origin/fat_max_origin)*1.5]);
hold on;
grid on;
plot(final_fat_dam(:,1),final_fat_dam(:,2)./fat_max_origin,'r');
hold on;
grid on;
scatter(x_max_origin,fat_max_origin./fat_max_origin,40,[1 0 1],'fill','o')
hold on;
grid on;
scatter(x_max_variation,fat_max_variation./fat_max_origin,40,[0 0.8 0],'fill','o')
set(gca,'YTick',0:0.1:(fat_max_origin/fat_max_origin)*1.5)
xlabel('Arclength [m]');
ylabel('Normalized fatigue [-]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100),' %',]);
legend('Original analysis','Analysis with (x,y) variation',...
['Fat. = ',num2str(fat_max_origin),' [1/years]',' at x = ',num2str(x_max_origin),...
' m'],['Fat. = ',num2str(fat_max_variation),' [1/years]',' at x = ',num2str(x_max_variation),' m']...
,'Location','Best');

%This is the way I can create my figures
name = ['norm_fatigue_damage_vs_variation_',num2str(xmin),'_',num2str(xmax)];
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;
%%




