%% Run sum_fatigue_damage() function...
clc;
clear all;

run_folder = 'C:\Users\Emir Lejlic\Documents\MATLAB\master_thesis\fatigue_damage_xy_variation\variation_coord_result_folders';

%Creating a struct with the important info:
run_data = save_run_xy_info_in_struct(run_folder);

%% Adding the fatigue damage to the run_data struct.
fatigue_file = 'fatigue_damage.txt';
run_data = add_fatigue_damage_to_struct(run_data, run_folder,fatigue_file);


%% Summing the fatigue

[final_fat_dam, sum_prob] = sum_fatigue_damage_from_xy_variation(run_data);

fprintf('Summed p(x,y): %6.3f %%.\n',sum_prob *100);

%% Some key values...
clc;
fat_max_origin = max(run_data(1,1).fatigue_damage(:,2));
indx_origin = find(run_data(1,1).fatigue_damage(:,2) == fat_max_origin);
fat_max_variation = max(final_fat_dam(:,2));
indx_variation = find(final_fat_dam(:,2) == fat_max_variation);


format shortg
x_max_origin = run_data(1,1).fatigue_damage(indx_origin,1);
x_max_variation = final_fat_dam(indx_variation,1);
format short

%This is the difference in x values...
dx = abs(x_max_origin-x_max_variation);

%If the difference is small, I set dx = 3. Look at the xlim in the figures.
    if dx < 3

        dx = 3;

    end
    
%% Finding the largest probable position
clc;
prob_values = zeros(length(run_data),1);

for i = 1:length(run_data)
   
    prob_values(i,1) = run_data(i,1).prob;
    
end

max_prob_indx = find(prob_values == max(prob_values));

run_data(max_prob_indx,1).axial_force(1:5,2)


%plotting the difference between the Most probable value axial force.
close all;

figure()
plot(run_data(1,1).fatigue_damage(1:end-1,1),run_data(1,1).axial_force(:,2))
%% Plotting the tensile forces envelope
close all;
%Colormap: HSV. There are several to choose from.
cc = lines(length(run_data));


figure()
hold on;

for i = 1:length(run_data)
   
    x = run_data(i,1).fatigue_damage(1:end-1,1);
    y = run_data(i,1).axial_force(:,2);
    
    plot(x,y,'Color',cc(i,:));
    
end
xlim([1400 x(end)]);
xlabel('Arclength [m]');
ylabel('Tensile force [kN]');

%This is the way I can create my figures
name = 'tensile_force_envelope_1400_end';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

figure()
hold on;
for i = 1:length(run_data)
   
    x = run_data(i,1).fatigue_damage(1,1);
    y = run_data(i,1).axial_force(1,2);
    
    scatter(x,y,40,cc(i,:),'fill','o');%,'Color',cc(i,:));40,[0 0.8 0],'fill','o'
    
end
grid on;
ylabel('Tensile force [kN]');
title(['Max/min: ',num2str(max_tensile,'%4.0f'),'/',num2str(min_tensile,'%4.0f'),' [kN]']);

%This is the way I can create my figures
name = 'tensile_force_RHoP';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;


%% Creating a matric with coords, axial force at RHoP and prob.
clc;
%Finding the max and min values:

%Preallocating the memory
vessel_coords = zeros(length(run_data),4);

for i = 1:length(run_data)   
    vessel_coords(i,1) = run_data(i,1).xpos;
    vessel_coords(i,2) = run_data(i,1).ypos;
    vessel_coords(i,3) = run_data(i,1).axial_force(1,2);
    vessel_coords(i,4) = run_data(i,1).prob;
end

max_tensile = max(vessel_coords(:,3));
min_tensile = min(vessel_coords(:,3));

%% Statistics of x-values

%Checking the probability for the vessel behind at x = 0, x > 0 and x < 0.
xprob_ahead_origin = 0;
xprob_behind_origin = 0;
xprob_origin = 0;

%Some valus may be really small, like 1.5e-14. That is larger than 0.
orig_lim = 0.1;

for i = 1:length(run_data)
   
    if vessel_coords(i,1) > orig_lim
        
        %Counting the prob for x > origin.
        xprob_ahead_origin = xprob_ahead_origin + vessel_coords(i,4);
        
    elseif vessel_coords(i,1) < -orig_lim
        
        %Counting the prob for x < origin.
        xprob_behind_origin = xprob_behind_origin + vessel_coords(i,4);
        
    else
        
        %Counting the prob. for x = origin.
        xprob_origin = xprob_origin + vessel_coords(i,4);
    
    end
    
end
clc;
fprintf('The probabilities are:\n');
fprintf('x-coord > 0: %3.2f\n',xprob_ahead_origin);
fprintf('x-coord = 0: %3.2f\n',xprob_origin);
fprintf('x-coord < 0: %3.2f\n\n',xprob_behind_origin);
fprintf('Sum prob: %3.2f\n',xprob_ahead_origin+xprob_behind_origin+xprob_origin);

%% Statistics of tensile forces.
%How many times are the tensile forces larger than at the origin.

%The tensile forces at the origin.
tensile_origin_rhop = vessel_coords(1,3);

%Finding if the probability is larger for greater tensile forces.
tensile_larger = 0;
tensile_origin = 0;
tensile_lower = 0;

for i = 1:length(run_data)

    %Tensile forces larger than in origin
    if vessel_coords(i,3) > tensile_origin_rhop
       
        tensile_larger = tensile_larger + vessel_coords(i,4);
        
    %Tensile forces lower than in origin.    
    elseif vessel_coords(i,3) < tensile_origin_rhop
        
        tensile_lower = tensile_lower + vessel_coords(i,4);
        
    %The tensile forces are the same as the origin.    
    else
        
        tensile_origin = tensile_origin + vessel_coords(i,4);
        
    end

end

fprintf('The probabilities are:\n');
fprintf('T_RHoP > T_orig: %3.2f\n',tensile_larger);
fprintf('T_RHoP < T_orig: %3.2f\n',tensile_lower);
fprintf('T_RHoP = T_orig: %3.2f\n\n',tensile_origin);
fprintf('Sum prob: %3.2f\n',tensile_larger+tensile_lower+tensile_origin);



%% Surface plot of the tensile forces

clc;

x_min = min(vessel_coords(:,1));
x_max = max(vessel_coords(:,1));

y_min = min(vessel_coords(:,2));
y_max = max(vessel_coords(:,2));

z_min = min(vessel_coords(:,3));
z_max = max(vessel_coords(:,3));

%Creating this for the meshgrid.
xlin = linspace(x_min,x_max,50);
ylin = linspace(y_min,y_max,50);

%Making the grid.
[X,Y] = meshgrid(xlin,ylin);

%The important parameters from the xy_counted_in_sectors.
x = vessel_coords(:,1);
y = vessel_coords(:,2);
tensile_forces = vessel_coords(:,3);

%Interpolating the probability at the discrete points.
f = scatteredInterpolant(x,y,tensile_forces,'natural','none');

%Z is now the surface function.
Z = f(X,Y);

%Plotting the surface and contour of the vessel movement probability.
clc;
close all;

tensile_forces = tensile_forces + 1;

figure();
mesh(X,Y,Z) 
hold on
axis([x_min x_max y_min y_max z_min z_max]);
surfc(X,Y,Z,'FaceLighting','phong');
shading interp
colorbar;
% hold on;
% scatter3(x,y,tensile_forces,5,'k','fill')
view(25,20);
%title('Tensile force at RHoP [kN]');
xlabel('x [m]');
ylabel('y [m]');
zlabel('Effective tension [kN]');

%This is the way I can create my figures
name = 'surf_tensileforce_RHoP';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

%% The contour of the surface.
close all;

figure()
contourf(X,Y,Z,30)
colorbar;
axis([x_min x_max y_min y_max]);
xlabel('x [m]');
ylabel('y [m]');
grid on;
legend('Tensile force at RHoP [kN]');


%This is the way I can create my figures
name = 'contour_tensileforce_RHoP';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;


    
%% Finding important parameters from the stamod.res file

%From the stamod.res file:
res_filename = 'sima_stamod.res';
run_data = find_important_parameters_resfile(run_data, run_folder, res_filename);

%% Finding the interval of the TDP 
TDP_x_values = zeros(1,length(run_data));
Prob_values = zeros(1,length(run_data));
for i = 1:length(run_data)
   
    TDP_x_values(i) = run_data(i,1).TDP_x_value;
    Prob_values(i) = run_data(i,1).prob;
    
end

min_TDP = min(TDP_x_values);
max_TDP = max(TDP_x_values);

plot_TDP_y = 0.15;
plot_TDP = [min_TDP plot_TDP_y; max_TDP plot_TDP_y];

%% Comparing the axial force of the riser...
close all;

%The axial matrix has one row less than the static config matrix.
axial_rows = size(run_data(1,1).axial_force,1);

%Preallocating memory.
axial_force_origin = zeros(axial_rows,2);
axial_force_variation = zeros(axial_rows,2);
axial_force_variation_tmp = zeros(axial_rows,1);

%The line length [m]. OBS: 1:end-1 because of one less row!!
axial_force_variation(:,1) = run_data(1,1).fatigue_damage(1:end-1,1);
axial_force_origin(:,1) = axial_force_variation(:,1);

%Important that the first row is (0,0).
axial_force_origin(:,2) = run_data(1,1).axial_force(:,2);

%Adding together all the axial forces with their respective probabilities.
for i = 1:length(run_data)
   
   prob = run_data(i,1).prob;
   axial_force_variation_tmp = prob .* run_data(i,1).axial_force(:,2);
   
   axial_force_variation(:,2) = axial_force_variation(:,2) + axial_force_variation_tmp(:,1);
    
    
end

%Calculating the deviation between the axial forces.
deviation = zeros(1,axial_rows);

for i = 1:axial_rows      
     deviation(i)  = abs(axial_force_origin(i,2)-axial_force_variation(i,2));
end

%Max deviation.
max_dev = max(deviation);

%% Copy folder

copy_to_folder = 'C:\Users\Emir Lejlic\Dropbox\Masteroppgave\Master_report\figures\xy_summation';

%% Plotting them to see the difference
figure()
plot(axial_force_variation(:,1),axial_force_variation(:,2),'-.b');
hold on;
plot(axial_force_origin(:,1),axial_force_origin(:,2),'--r');
title(['Max deviation between the axial forces: ',num2str(max_dev),' [kN]'])
xlabel('Riser length [m]');
ylabel('Effective tension [kN]');
legend('Original analysis','Variation of (x,y) analysis','Location','Best');

%This is the way I can create my figures
name = 'comparing_axial_tension';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

%% The plot
close all;

figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2),'b')
xlim([0 1800]);
hold on;
grid on;
plot(final_fat_dam(:,1),final_fat_dam(:,2),'r');
hold on;
grid on;
scatter(x_max_origin,fat_max_origin,40,[1 0 1],'fill','o')
hold on;
grid on;
scatter(x_max_variation,fat_max_variation,40,[0 0.8 0],'fill','o')
xlabel('Arclength [m]');
ylabel('Fatigue [1/year]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100,'%3.1f'),' %',]);
legend('Original analysis','Analysis with (x,y) variation',...
['Fat. = ',num2str(fat_max_origin,'%3.2f'),' [1/years]',' at x = ',num2str(x_max_origin,'%4.0f'),...
' m'],['Fat. = ',num2str(fat_max_variation,'%3.2f'),' [1/years]',' at x = ',num2str(x_max_variation,'%4.0f'),' m']...
,'Location','Best');

%This is the way I can create my figures
name = 'fatigue_damage_vs_variation_whole';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2),'b')
xlim([((x_max_variation+x_max_origin)/2)-(3*dx) 1750]);
ylim([0 fat_max_origin*1.5]);
hold on;
grid on;
plot(final_fat_dam(:,1),final_fat_dam(:,2),'r');
hold on;
grid on;
scatter(x_max_origin,fat_max_origin,40,[1 0 1],'fill','o')
hold on;
grid on;
scatter(x_max_variation,fat_max_variation,40,[0 0.8 0],'fill','o')
xlabel('Arclength [m]');
ylabel('Fatigue [1/year]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100,'%3.1f'),' %',]);
legend('Original analysis','Analysis with (x,y) variation',...
['Fat. = ',num2str(fat_max_origin,'%3.2f'),' [1/years]',' at x = ',num2str(x_max_origin,'%4.0f'),...
' m'],['Fat. = ',num2str(fat_max_variation,'%3.2f'),' [1/years]',' at x = ',num2str(x_max_variation,'%4.0f'),' m']...
,'Location','Best');

%This is the way I can create my figures
name = 'fatigue_damage_vs_variation_closeup';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;


figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2)./fat_max_origin,'b')
xlim([0 1800]);
hold on;
grid on;
plot(final_fat_dam(:,1),final_fat_dam(:,2)./fat_max_origin,'r');
hold on;
grid on;
scatter(x_max_origin,fat_max_origin./fat_max_origin,40,[1 0 1],'fill','o')
hold on;
grid on;
scatter(x_max_variation,fat_max_variation./fat_max_origin,40,[0 0.8 0],'fill','o')
xlabel('Arclength [m]');
ylabel('Normalized fatigue [-]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100,'%3.1f'),' %',]);
legend('Original analysis','Analysis with (x,y) variation',...
['Fat. = ',num2str(fat_max_origin,'%3.2f'),' [1/years]',' at x = ',num2str(x_max_origin,'%4.0f'),...
' m'],['Fat. = ',num2str(fat_max_variation,'%3.2f'),' [1/years]',' at x = ',num2str(x_max_variation,'%4.0f'),' m']...
,'Location','Best');

%This is the way I can create my figures
name = 'norm_fatigue_damage_vs_variation_whole';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;
%%
close all;

figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2)./fat_max_origin,'b')
xlim([((x_max_variation+x_max_origin)/2)-(3*dx) 1730]);
ylim([0 (fat_max_origin/fat_max_origin)*1.0]);
hold on;
grid on;
plot(final_fat_dam(:,1),final_fat_dam(:,2)./fat_max_origin,'r');
hold on;
grid on;
scatter(x_max_origin,fat_max_origin./fat_max_origin,40,[1 0 1],'fill','o')
hold on;
grid on;
scatter(x_max_variation,fat_max_variation./fat_max_origin,40,[0 0.8 0],'fill','o')

set(gca,'YTick',0:0.1:(fat_max_origin/fat_max_origin)*1.5)
xlabel('Arclength [m]');
ylabel('Normalized fatigue [-]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100,'%3.1f'),' %',]);

%This is the way I can create my figures
name = 'norm_fatigue_damage_vs_variation_close';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

xmin = 1200;
xmax = 1750;

figure()
plot(run_data(1,1).fatigue_damage(:,1),run_data(1,1).fatigue_damage(:,2)./fat_max_origin,'b')
xlim([xmin xmax]);
ylim([0 (fat_max_origin/fat_max_origin)*1.5]);
hold on;
grid on;
plot(final_fat_dam(:,1),final_fat_dam(:,2)./fat_max_origin,'r');
hold on;
grid on;
scatter(x_max_origin,fat_max_origin./fat_max_origin,40,[1 0 1],'fill','o')
hold on;
grid on;
scatter(x_max_variation,fat_max_variation./fat_max_origin,40,[0 0.8 0],'fill','o')
set(gca,'YTick',0:0.1:(fat_max_origin/fat_max_origin)*1.5)
xlabel('Arclength [m]');
ylabel('Normalized fatigue [-]');
title(['Sum p(x,y) from all runs: ',num2str(sum_prob*100,'%3.1f'),' %']);
legend('Original analysis','Analysis with (x,y) variation',...
['Fat. = ',num2str(fat_max_origin,'%3.2f'),' [1/years]',' at x = ',num2str(x_max_origin,'%4.0f'),...
' m'],['Fat. = ',num2str(fat_max_variation,'%3.2f'),' [1/years]',' at x = ',num2str(x_max_variation,'%4.0f'),' m']...
,'Location','Best');

%This is the way I can create my figures
name = ['norm_fatigue_damage_vs_variation_',num2str(xmin),'_',num2str(xmax)];
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;
%% Example of one fatigue damage plot
close all;

figure()
plot(run_data(1,1).fatigue_damage(:,1), run_data(1,1).fatigue_damage(:,2),'LineWidth',1.0);
xlim([0 1800]);
grid on;
xlabel('Arclength [m]');
ylabel('Fatigue damage [1/year]');

%This is the way I can create my figures
name = 'example_fatigue_dam';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;