function run_data = save_run_xy_info_in_struct(run_folder)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This function goes through all the folders containing the info of the
%(x,y) coordinate variation runs and saves it in a struct for further 
%processing.
%
%Name: Emir Lejlic.
%Date: 08.05.13
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%These are needed to extract the run info needed.
list = dir(run_folder);

%Saving all the names
name = {list.name};
%Creating a string of the names, with a # between each folder.
str = sprintf('%s#', name{:});

%Finding the important strings to be able to sort the names.
find_run = strfind(str,'Run');
find_xpos = strfind(str,'xpos');

%Preallocating the for the numbers...
num = zeros(1,length(find_run));

    %Saving the run numbers
    for i = 1:length(find_run)        
        num(i) = sscanf(str(find_run(i):find_xpos(i)-1), 'Run_%d');
    end
    
%This is the way to find the index of the numbers. The run is the sorted
%numbers.
[~, index] = sort(num);

%Creating a new struct which will only contain the run info.
run_data(size(list,1)-2,1) = struct();

    %Adding the sorted folder names to the struct.
    for i = 1:length(index)
        
        run_data(i,1).name = list(index(i)+2,1).name;

    end

    for i = 1:length(run_data)
    
    %Finding these strings in the name.
    str_xpos = strfind(run_data(i,1).name,'xpos');
    str_ypos = strfind(run_data(i,1).name,'ypos');
    str_prob = strfind(run_data(i,1).name,'prob');
    
    %Extracting the values.
    x_str = run_data(i,1).name(str_xpos+length('xpos'):str_ypos-1);
    y_str = run_data(i,1).name(str_ypos+length('ypos'):str_prob-1);
    prob_str = run_data(i,1).name(str_prob+length('prob'):end);
    
    %Replacing the underscores (_) with dots (.)(.)
    x_str = strrep(x_str,'_','.');
    y_str = strrep(y_str,'_','.');
    prob_str = strrep(prob_str,'_','.');
    
    %Now, converting the string values to numbers.
    run_data(i,1).xpos = str2double(x_str);
    run_data(i,1).ypos = str2double(y_str);
    run_data(i,1).prob = str2double(prob_str); 
          
    end


end

