function matrix = ReadMPF(filename)
% ReadMPF - get the data from *.mpf files generated by RIFLEX
%
% Get the matrices that match the string title from the mpf file mpffile.
% 
% Input:
% filename - the complete name of the *.mpf file
%
% Ouput:
%  matrix(iMat).name   (string)
%  matrix(iMat).title  (string)
%  matrix(iMat).xlabel (string)
%  matrix(iMat).ylabel (string)
%  matrix(iMat).legend (cell array of strings)
%  matrix(iMat).values (2D array)
%
%  Programmed by Elizabeth Passano 02-01-23
%  Modified   by Philippe Maincon  07-05-16
%  Modified   by Emir Lejlic       27.02.2013
% 
% $Author: elizabep $ $DateTime: 2011/05/20 17:06:36 $

filetext  = file2str(filename);

%Deletes the last 11 chars of the filetext. They are not necessary.
filetext  = filetext(1:end-11);

%Find start of all matrices on file + dummy pointer at end
ixmat = [strfind(filetext,'MATRIX') length(filetext)];

%Occurences of 'MATRIX' in the textfile. -1 because of the dummy pointer.
nmat  = length(ixmat)-1;

%Goes out of the scritp if no 'MATRIX' are found
if nmat == 0 
    matrix = [];
    return
end

%This command creates a struct that has the dimesnion (1 x nmat)
matrix(nmat)  = struct();

for imat = 1:nmat
    
    %EMLE: need to have -1 in the end to avoid the first char of next
    %matrix
    mattext   = filetext(ixmat(imat):(ixmat(imat+1)-1));

    %Reading the strings after 'MATRIX', 'TITLE' etc... The first number
    %indicates the row in the mattext.
    
    %strtrim removes the whitespace in fron and back of the strings.
    matrix(imat).name     = strtrim(ReadTokenLine(1,mattext,'MATRIX'));

    title_temp_1 = strtrim(ReadTokenLine(2,mattext,'TITLE'));
    
    if strcmp(mattext,'SUBTITLE') == 1
       Sub_place = strfind(mattext,'SUBTITLE');
       
    end
    
    %These lines are needed in order to create .png files without (: . , whitespace)
    title_temp_2 = strrep(title_temp_1,' ','_');
    
    title_temp_3 = strrep(title_temp_2,':','_');
    
    title_temp_4 = strrep(title_temp_3,',','_');
    
    title_temp_5 = strrep(title_temp_4,'.','_');
    
    title = strrep(title_temp_5,'__','_');
    
    
    
    %The formatted title 
    matrix(imat).title = title;    
    
    %The stamod.mpf contains a headerline with 'SUBTITLE'. This is 
    %unnecessary and will be removed with RemoveLineWithToken 
    subtitle = strfind(mattext,'SUBTITLE');
    
        if isempty(subtitle) == false
       
            mattext = RemoveLineWithToken(mattext,'SUBTITLE');
        
        end
    
    matrix(imat).xlabel   = strtrim(ReadTokenLine(3,mattext,'XLABEL'));
    
    matrix(imat).ylabel   = strtrim(ReadTokenLine(4,mattext,'YLABEL'));

    legend                = strtrim(ReadTokenLine(5,mattext,'LEGENDS'));
    
    %fnut has the info of where all ' are in the line, so that it is
    %possible to get text between two ' '.
    fnut = strfind(legend,'''');
       
    %My own for-loop. A bit modified.
    for i = 1:length(fnut)/2
        
        %Finds the first and last letter in between every '' in the legend
        %line.
        first_let = fnut(2*i-1)+1;
        last_let  = fnut(2*i)-1;
    
        matrix(imat).legend{i} = legend(first_let:last_let);
    
    end    
    
    %iValues give the position of 'VALUES'.
    iValues = strfind(mattext,'VALUES');
    %strrep replaces 'VALUES' with an empty field ''. 
    mattext = strrep(mattext(iValues:end),'VALUES','');
    %Read data into a matrix
    matrix(imat).values = str2num(mattext);    
    
    %matrix(imat).values   = str2num(strrep(mattext(iValues:end),'VALUES',''));
end


end

%The function ReadTokenLine is used to read the line in which the token
%searched for is.

%Inserted line_no in order to get all of the information from the five
%lines that contain info in each mattext part.

function line = ReadTokenLine(line_no,text,token)

    [b,e] = FindLines(text);
   
    line = text(b(line_no)+10:e(line_no));
    
end
