function new_text = RemoveLineWithToken(filetext,token)
%Created by: Emir Lejlic.
%Date:       28.02.2013
%
%This function gets a filetext as input, and deletes the string line with
%an unnecessary header. The output is the text without that line.
%
%The input:     filetext --> must have been converted to a string
%               token -->    A header that is a string and is at the start 
%                            of a line 'string'
%--------------------------------------------------------------------------
%   Example:
%   filetext = file2str('mpf_with_subtitle.txt');
%   
%   filetext =
%   XLABEL    X-coordinate [m]
%   YLABEL    Z-coordinate [m]
%   LEGENDS   'X' 'XZ'  HEADING
%
%   RemoveLineWithToken(filetext,'YLABEL')
%
%   new_text =
%
%   XLABEL    X-coordinate [m]
%   LEGENDS   'X' 'XZ'  HEADING
%--------------------------------------------------------------------------

%Finds the start (b) and end (e) of each line
[b e] = FindLines(filetext);

%Finds the pos. of the token in filetext
found_str = strfind(filetext,token);

%The while loop will search for the pos. of token, and find in which line
%it is.
counter = 1;

    while b(counter) ~= found_str   
        counter = counter + 1;
    end

%Removing the representative line
new_text = strrep(filetext,filetext(b(counter)-1:e(counter)+1),'');

end
