%% This script is looking what angle and parts of sector change the results.

clc;
%The largest radius creates the boundary.
largest_radius = ceil(max(xy_polar_cord_prob(:,3)));
%The angle size of each sector.
sector_degree = 30;
%How many parts each sector has.
sector_parts = 5;

xy_counted_in_sectors = ...
search_xy_in_sectors(xy_polar_cord_prob,sector_degree,largest_radius,sector_parts);

%% Plotting the scatterdata of the discrete points.

figure_folder = 'C:\Users\Emir Lejlic\Dropbox\Masteroppgave\Master_report\figures';
xy_stat_folder = 'xy_statistics';
subfolder = strcat('sector_parts_',num2str(sector_parts),'_deg_',num2str(sector_degree));

copy_to_folder = fullfile(figure_folder,xy_stat_folder,subfolder);

%This function checks if the figure folder exist in current directory. 
%If not, it will create one. Check exist on the internet for more info.
if exist(copy_to_folder,'dir') ~= 7 
    mkdir(copy_to_folder);
end


%%

close all;

%Discrete points probability
figure()
x = xy_counted_in_sectors(:,1);
y = xy_counted_in_sectors(:,2);
z = xy_counted_in_sectors(:,7);
scatter3(x,y,z,30,'MarkerFaceColor','r');
set(gca,'XTick',-50:15:50)
set(gca,'YTick',-50:15:50)
%axis equal;
grid on;
xlabel('x [m]');
ylabel('y [m]');
zlabel('Probability at (x_i,y_i)');

%This is the way I can create my figures
name = 'discrete_scatter_prob';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

%The discrete points from above
figure()
x = xy_counted_in_sectors(:,1);
y = xy_counted_in_sectors(:,2);
z = xy_counted_in_sectors(:,7);
scatter3(x,y,z,30,'MarkerFaceColor','c');
view([0 0 10]);
set(gca,'XTick',-50:10:50)
set(gca,'YTick',-50:10:50)
%axis equal;
grid on;
xlabel('x [m]');
ylabel('y [m]');

%This is the way I can create my figures
name = 'discrete_scatter_prob_Zview';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

% Using the discrete scattered data to create a function Z which will create a surface plot.
%The surface plot is just to have a better picture of how the points are
%connected.
x_min = min(xy_counted_in_sectors(:,1));
x_max = max(xy_counted_in_sectors(:,1));

y_min = min(xy_counted_in_sectors(:,2));
y_max = max(xy_counted_in_sectors(:,2));

%The largest probability.
z_max = max(xy_counted_in_sectors(:,7));

%Creating this for the meshgrid.
xlin = linspace(x_min,x_max,100);
ylin = linspace(y_min,y_max,100);

%Making the grid.
[X,Y] = meshgrid(xlin,ylin);

%The important parameters from the xy_counted_in_sectors.
x = xy_counted_in_sectors(:,1);
y = xy_counted_in_sectors(:,2);
prob = xy_counted_in_sectors(:,7);

%Interpolating the probability at the discrete points.
f = scatteredInterpolant(x,y,prob,'linear','none');

%Z is now the surface function.
Z = f(X,Y);

%Plotting the surface and contour of the vessel movement probability.
clc;
close all;

figure();
mesh(X,Y,Z) 
hold on
axis([x_min x_max y_min y_max 0 z_max]);
surf(X,Y,Z,'FaceLighting','phong');
view(60,40);
title('The (x,y) probability.');
xlabel('x [m]');
ylabel('y [m]');
zlabel('p(x,y) [-]');
shading interp
colorbar;

%This is the way I can create my figures
name = 'surface_discrete_points';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

% The contour of the surface.
close all;
axis_lim =13;

figure()
contourf(X,Y,Z)
axis([-axis_lim axis_lim -axis_lim axis_lim]);
xlabel('x [m]');
ylabel('y [m]');
grid on;
legend('p(x,y)');
colorbar;

name = 'contour_of_surface';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;