function [counted_x_y_data, large_transformed_coord_matrix, total_count] ...
    = count_in_large_matrix(x_y_motion, x_data_rows, x_pos_files,...
                            y_max_trans, x_max_trans, x_min, y_max)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                        
%This function goes through all the transformed, multiplied coordinates,
%and inserts the number of occurences into a large matrix.
%
%Date: 23.04.13
%Name: Emir Lejlic.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Since the coord. system is transformed, the y_max will give how many rows
%that will be necessary, and how many

%These values are needed to transform back to the original coordinates:
x_start = x_min;
y_start = y_max;

large_transformed_coord_matrix = zeros(y_max_trans, x_max_trans);

%Creating a 100000 x 2 matrix to store the results:
%| x | y |

%The matrix has to be large enough to store all the results. To store the
%number of counts, the total_counter is used.
counted_x_y_data = zeros(100000,2);

%The total count will give the final count of all occurences.
total_count = 0;

%This counter will help store the results in the counted_x_y_data matrix.
counter = 1;

fprintf('\nInserting the occurences into the large matrix:\n');
    
    for i = 1:x_pos_files
        
        fprintf('%i out of %i files finished.\n',i,x_pos_files);

        for j = 1:x_data_rows

            total_count = total_count + 1;

            %The transformed x-value corresponds to the m-index in the large
            %matrix. The same is with the n-index and the transformed y-value.
            m = x_y_motion(i,1).x_y_data(j,5);
            n = x_y_motion(i,1).x_y_data(j,6);

            large_transformed_coord_matrix(n,m) = large_transformed_coord_matrix(n,m) + 1;

               %Counting which coordinates are being registered.
               if large_transformed_coord_matrix(n,m) == 1

                  %Dividing by 100 to get the transformed coords.
                   x_transformed = m/100;
                   y_transformed = n/100;

                   %Transforming the coord back to the original ones.
                   x = x_transformed + x_start;
                   y = y_start - y_transformed;

                   counted_x_y_data(counter,1) = x;
                   counted_x_y_data(counter,2) = y;

                   counter = counter + 1;

               end
         end
    end    
    
    %Deleting the unecessary empty cells:    
    counted_x_y_data(counter:end,:) = [];

end

