function discrete_points = create_discrete_point(sector_degree,largest_coord_pos, sector_parts)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%The function creates a matrix with the needed discrete points in the
%sectors that go 360 degrees around.
%
%Date: 28.04.13
%Name: Emir Lejlic.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Number of sectors.
no_sectors = 360/sector_degree;

%These theta values are used in the for loop.
theta = (sector_degree/2):sector_degree:(360-sector_degree/2);

%Sector parts define how many intervals there is inside a sector. This will
%create the borders which will be borders for the counting of the
%positions.
sector_radius = 0:(largest_coord_pos/sector_parts):largest_coord_pos;

%Creating a matrix with the needed discrete points.
%| x | y | r | sector_start | sector_end |
discrete_points = zeros((no_sectors*(sector_parts))+1,5);

%Needed to add the discrete points in the matrix.
counter = 2;

%This for loop creates the needed discrete points.
    for i = 1:no_sectors

        theta_end = theta(i);
        theta_start = theta_end - sector_degree;    
           
        %The discrete points ly on this angle.
        theta_discrete_deg = (theta_end + theta_start)/2;
        theta_discrete_rad = theta_discrete_deg * (pi/180);
        
         %Needed to not get negative angles.
            if theta_start < 0
               
                theta_start = 360 - theta_end;
                
            end

        for j = 2:length(sector_radius)
            
            x = sector_radius(j)*cos(theta_discrete_rad);
            y = sector_radius(j)*sin(theta_discrete_rad);        
           
            %Saving the discrete coords. in the matrix. The first
            %coordinate is the origin (0,0).
            discrete_points(counter,1) = x;
            discrete_points(counter,2) = y;
            discrete_points(counter,3) = sqrt(x.^2 + y.^2);
            discrete_points(counter,4) = theta_start;
            discrete_points(counter,5) = theta_end;
            
            counter = counter + 1;        
           
        end

    end

end

