%% This script is looking what angle and parts of sector change the results.
checking_sector_parts = [5 6 7 8 9 10 12 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];

%Will save the coordinates with largest prob in these matrices.
max_yvalues = zeros(1,length(checking_sector_parts));
max_xvalues = zeros(1,length(checking_sector_parts));
max_probvalues = zeros(1,length(checking_sector_parts));

for i = 1:length(checking_sector_parts)

close all;
clc;

%The largest radius creates the boundary.
largest_radius = ceil(max(xy_polar_cord_prob(:,3)));
%The angle size of each sector.
sector_degree = 30;
%How many parts each sector has.
sector_parts = checking_sector_parts(i);

xy_counted_in_sectors = ...
search_xy_in_sectors(xy_polar_cord_prob,sector_degree,largest_radius,sector_parts);

% Plotting the scatterdata of the discrete points.

figure_folder = 'C:\Users\Emir Lejlic\Dropbox\Masteroppgave\Master_report\figures';
xy_stat_folder = 'xy_statistics';
subfolder = 'discretisation_problems';

copy_to_folder = fullfile(figure_folder,xy_stat_folder,subfolder);

%This function checks if the figure folder exist in current directory. 
%If not, it will create one. Check exist on the internet for more info.
if exist(copy_to_folder,'dir') ~= 7 
    mkdir(copy_to_folder);
end


%Discrete points probability
figure('Visible','off')
x = xy_counted_in_sectors(:,1);
y = xy_counted_in_sectors(:,2);
z = xy_counted_in_sectors(:,7);
scatter3(x,y,z,30,'MarkerFaceColor','r');
set(gca,'XTick',-50:15:50)
set(gca,'YTick',-50:15:50)
%axis equal;
grid on;
xlabel('x [m]');
ylabel('y [m]');
zlabel('Probability at (x_i,y_i)');

%This is the way I can create my figures
name = strcat('prob_discrete_points_parts_',num2str(checking_sector_parts(i)));
name_pdf = strcat(name,'.pdf');
export_fig(name_pdf,'-pdf','-transparent','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
clear name name_pdf;

%The discrete points from above
figure('Visible','off')
x = xy_counted_in_sectors(:,1);
y = xy_counted_in_sectors(:,2);
scatter(x,y,30,'MarkerFaceColor','c');
set(gca,'XTick',-50:10:50)
set(gca,'YTick',-50:10:50)
%axis equal;
grid on;
xlabel('x [m]');
ylabel('y [m]');

%This is the way I can create my figures
name = strcat('discrete_points_parts_',num2str(checking_sector_parts(i)));
name_pdf = strcat(name,'.pdf');
export_fig(name_pdf,'-pdf','-transparent','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
clear name name_pdf;

% Using the discrete scattered data to create a function Z which will create a surface plot.
%The surface plot is just to have a better picture of how the points are
%connected.
x_min = min(xy_counted_in_sectors(:,1));
x_max = max(xy_counted_in_sectors(:,1));

y_min = min(xy_counted_in_sectors(:,2));
y_max = max(xy_counted_in_sectors(:,2));

%The largest probability.
z_max = max(xy_counted_in_sectors(:,7));

%Creating this for the meshgrid.
xlin = linspace(x_min,x_max,100);
ylin = linspace(y_min,y_max,100);

%Making the grid.
[X,Y] = meshgrid(xlin,ylin);

%The important parameters from the xy_counted_in_sectors.
x = xy_counted_in_sectors(:,1);
y = xy_counted_in_sectors(:,2);
prob = xy_counted_in_sectors(:,7);

max_prob = max(prob);
[iindx, ~] = find(xy_counted_in_sectors(:,7) == max_prob);

max_prob_x = xy_counted_in_sectors(iindx,1);
max_prob_y = xy_counted_in_sectors(iindx,2);

max_xvalues(i) = max_prob_x;
max_yvalues(i) = max_prob_y;
max_probvalues(i) = max_prob;

%Interpolating the probability at the discrete points.
f = scatteredInterpolant(x,y,prob,'linear','none');

%Z is now the surface function.
Z = f(X,Y);

%Plotting the surface and contour of the vessel movement probability.

figure('Visible','off')
mesh(X,Y,Z) 
hold on
axis([x_min x_max y_min y_max 0 z_max]);
surf(X,Y,Z,'FaceLighting','phong');
view(60,40);
title('The (x,y) probability.');
xlabel('x [m]');
ylabel('y [m]');
zlabel('p(x,y) [-]');
shading interp
colorbar;

%This is the way I can create my figures
% name = 'surface_discrete_points';
% name_pdf = strcat(name,'.pdf');
% name_eps = strcat(name,'.eps');
% export_fig(name_pdf,'-pdf','-transparent','-painters');
% print(gcf,name_eps,'-depsc2','-painters');
% 
% copyfile(name_pdf,copy_to_folder);
% delete(name_pdf);
% copyfile(name_eps,copy_to_folder);
% delete(name_eps);
% clear name name_eps name_pdf;

% The contour of the surface.
close all;
axis_lim =15;

figure('Visible','off')
contourf(X,Y,Z,9)
axis([-axis_lim axis_lim -axis_lim axis_lim]);
xlabel('x [m]');
ylabel('y [m]');
grid on;
legend('p(x,y)');
colorbar;

name = strcat('contour_parts_',num2str(checking_sector_parts(i)));
name_pdf = strcat(name,'.pdf');
export_fig(name_pdf,'-pdf','-r300','-transparent','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
clear name name_pdf;

end

%%

% The max values
%Will save the coordinates with largest prob in these matrices.
close all;
max_yvalues;
max_xvalues; 
max_probvalues;

%Findning the data from the raw data
max_prob_raw = max(xy_coord_prob(:,4));
[iindx, ~] = find(xy_coord_prob(:,4) == max_prob_raw);

x_max_raw = xy_coord_prob(iindx,1);
y_max_raw = xy_coord_prob(iindx,2);
% 
% % Finding the second largest prob value, using the sorted values from excel
% clc;
% sorted_prob = zeros(size(xy_coord_prob,1),2);
% 
% sorted_prob(:,1) = xy_coord_prob(:,4);
% sorted_prob(:,2) = sort(sorted_prob(:,1),'descend');
% %
% points_to_check = 20;
% max_rawprob_data = zeros(points_to_check,4);
% 
% %
% 
% for i = 1:points_to_check
%    
%     prob_tmp = sorted_prob(i,1);
%     [iindx, ~] = find(xy_coord_prob(:,4) == prob_tmp);
%     
%     max_rawprob_data(i,1) = i;
%     max_rawprob_data(i,2) = xy_coord_prob(iindx,1);
%     max_rawprob_data(i,3) = xy_coord_prob(iindx,2);
%     max_rawprob_data(i,4) = prob_tmp;
%     
%      
% end
% 
% max_rawprob_data;
% 
% % Plotting the x-y values of the 20th largest prob points
% close all;
% clc;
% 
% figure()
% hold on;
% x = max_rawprob_data(:,2);
% y = max_rawprob_data(:,3);
% plot(x,y,'--r');
% hold on;
% scatter(x,y,40,'b','fill')



figure()
x = 1:length(max_probvalues);
y = max_probvalues;
plot(x,y,'--b','LineWidth',2)
hold on;
h_dot5_10 = scatter(x(1:6),y(1:6),40,'MarkerFaceColor','r','MarkerEdgeColor','none');
hold on;
h_dot12 = scatter(x(7),y(7),50,'MarkerFaceColor','g','MarkerEdgeColor','none');
hold on;
h_dot13_end = scatter(x(8:end),y(8:end),40,'MarkerFaceColor','r','MarkerEdgeColor','none');
grid on;
set(gca, 'XTick',x, 'XTickLabel',checking_sector_parts)
xlabel('Sector parts [-]')
ylabel('Max probability [-]');

name = 'max_prob_changes';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

% Comparing prob from raw data with the discretisation.

figure()
x = 1:length(max_probvalues);
y = max_probvalues;
plot(x,y,'--b','LineWidth',2)
hold on;
h_dot5_10 = scatter(x(1:6),y(1:6),40,'MarkerFaceColor','r','MarkerEdgeColor','none');
hold on;
h_dot12 = scatter(x(7),y(7),50,'MarkerFaceColor','g','MarkerEdgeColor','none');
hold on;
h_dot13_end = scatter(x(8:end),y(8:end),40,'MarkerFaceColor','r','MarkerEdgeColor','none');
hold on;
h_prob_raw = line('XData',[x(1) x(end)],'YData',[max_prob_raw max_prob_raw],'Color','m','LineWidth',1.5);
grid on;
ylim([-0.01 0.08]);
xlim([x(6) x(end)]);
set(gca, 'XTick',x, 'XTickLabel',checking_sector_parts)
xlabel('Sector parts [-]')
ylabel('Max probability [-]');
legend(h_prob_raw,['Max p(x,y) = ',num2str(max_prob_raw,'%4.3f'),' from SIMO analysis.']);

name = 'comparing_prob';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

figure()
x = 1:length(max_probvalues);
y = max_xvalues;
plot(x,y,'--b','LineWidth',2)
hold on;
h_dot5_10 = scatter(x(1:6),y(1:6),40,'MarkerFaceColor','r','MarkerEdgeColor','none');
hold on;
h_dot12 = scatter(x(7),y(7),50,'MarkerFaceColor','g','MarkerEdgeColor','none');
hold on;
h_dot13_end = scatter(x(8:end),y(8:end),40,'MarkerFaceColor','r','MarkerEdgeColor','none');
hold on;
h_x_raw = line('XData',[x(1) x(end)],'YData',[x_max_raw x_max_raw],'Color','m','LineWidth',1.5);
grid on;
set(gca, 'XTick',x, 'XTickLabel',checking_sector_parts)
xlabel('Sector parts [-]')
ylabel('x coord with max prob. [m]');
legend([h_dot12 h_x_raw],'Used in analysis',['x-coord = ',num2str(x_max_raw,'%3.2f'),' [m]',sprintf('\nfrom SIMO analysis.')])
%legend(h_x_raw,['x-coord = ',num2str(x_max_raw,'%3.2f'),' [m]',sprintf('\nfrom raw data.')])

name = 'x_maxprob_changes';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

figure()
x = 1:length(max_probvalues);
y = max_yvalues;
plot(x,y,'--b','LineWidth',2)
hold on;
h_dot5_10 = scatter(x(1:6),y(1:6),40,'MarkerFaceColor','r','MarkerEdgeColor','none');
hold on;
h_dot12 = scatter(x(7),y(7),50,'MarkerFaceColor','g','MarkerEdgeColor','none');
hold on;
h_dot12 = scatter(x(8:end),y(8:end),40,'MarkerFaceColor','r','MarkerEdgeColor','none');
hold on;
h_y_raw = line('XData',[x(1) x(end)],'YData',[y_max_raw y_max_raw],'Color','m','LineWidth',1.5);
grid on;
set(gca, 'XTick',x, 'XTickLabel',checking_sector_parts)
xlabel('Sector parts [-]')
ylabel('y coord with max prob. [m]');
legend(h_y_raw,['y-coord = ',num2str(y_max_raw,'%3.2f'),' [m]',sprintf('\nfrom SIMO analysis.')],'Location','Best')

name = 'y_maxprob_changes';
name_pdf = strcat(name,'.pdf');
name_eps = strcat(name,'.eps');
export_fig(name_pdf,'-pdf','-transparent','-painters');
print(gcf,name_eps,'-depsc2','-painters');

copyfile(name_pdf,copy_to_folder);
delete(name_pdf);
copyfile(name_eps,copy_to_folder);
delete(name_eps);
clear name name_eps name_pdf;

% %% Inserting the maxprob, ymaxprob and xmaxprob values into a table
% clc;
% max_table = zeros(length(max_probvalues),4);
% 
% max_table(:,1) = checking_sector_parts';
% max_table(:,2) = max_xvalues';
% max_table(:,3) = max_yvalues';
% max_table(:,4) = max_probvalues';
% 
% max_table







