function xy_counted_in_sectors = ...
search_xy_in_sectors(xy_polar_cord_prob,sector_degree,largest_coord_pos, sector_parts)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This function will go through the sectors and discrete points defined in 
%the input, and count the occurences of the (x,y) postion of the vessel.
%
%Date: 28.04.13
%Name: Emir Lejlic.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Number of sectors.
no_sectors = 360/sector_degree;

%These theta (angle) values are used in the for loop.
theta =(sector_degree/2):sector_degree:(360-sector_degree/2);

%Sector parts define how many intervals there is inside a sector. This will
%create the borders which will be borders for the counting of the
%positions.
delta_radius = (largest_coord_pos/sector_parts);
sector_radius = 0:delta_radius:largest_coord_pos;

%Finding the discrete points and creating a matrix for it.
discrete_points = create_discrete_point(sector_degree,largest_coord_pos, sector_parts);

%Creating the matrix for the final results.
%| x | y | r | sector_start | sector_end | counts | prob |
xy_counted_in_sectors = zeros((no_sectors * (sector_parts-1)) + 1,7);

%Starting the counter for the while loops.
i = 1;
j = 1;

%Need this counter to jump to new sector coords.
counter = 1;

%Used to check when xy_rows > 1.
xy_counter = 1;

    %Setting the points inside to sector_parts.
    while j <= size(xy_counted_in_sectors,1)
    
        if i == 1

            xy_counted_in_sectors(j,1) = discrete_points(i,1);
            xy_counted_in_sectors(j,2) = discrete_points(i,2);         
            %Inserting the radius.
            xy_counted_in_sectors(j,3) = discrete_points(i+1,3);
            %Inserting the degrees:
            xy_counted_in_sectors(j,4) = discrete_points(i,4);
            xy_counted_in_sectors(j,5) = discrete_points(i,5);           
                                   
            i = i + 1;
            j = j + 1;
                
        elseif (i > 1) && (i < size(discrete_points,1)-1) 

            xy_counted_in_sectors(j,1) = (discrete_points(i,1) + discrete_points(i+1,1))/2;
            xy_counted_in_sectors(j,2) = (discrete_points(i,2) + discrete_points(i+1,2))/2;
            xy_counted_in_sectors(j,3) =  discrete_points(i+1,3);
            
            %Inserting the degrees:
            xy_counted_in_sectors(j,4) = discrete_points(i,4);
            xy_counted_in_sectors(j,5) = discrete_points(i,5);
            
            i = i + 1;
            j = j + 1;
            
            counter = counter + 1;
            
                %This is needed when all the points are checked in one
                %sector.
                if counter == length(sector_radius)-1
                    
                    %Extra jump.
                    i = i + 1;
                    %Resetting the counter.
                    counter = 1;

                end          
           
        else 
            
            xy_counted_in_sectors(j,1) = (discrete_points(i,1) + discrete_points(i+1,1))/2;
            xy_counted_in_sectors(j,2) = (discrete_points(i,2) + discrete_points(i+1,2))/2;
            xy_counted_in_sectors(j,3) =  discrete_points(i+1,3); 
            
            %Inserting the degrees:
            xy_counted_in_sectors(j,4) = discrete_points(i,4);
            xy_counted_in_sectors(j,5) = discrete_points(i,5);
            
            i = i + 1;
            j = j + 1;
        end

    end
    
clear i j;
    
    fprintf('Looping through the sectors...\n');
    %This for loop will find the probability in the discrete points.
    for i = 1:no_sectors
        
         fprintf('%i of %i sectors checked.\n',i,no_sectors);
        
         theta_end = theta(i);
         theta_start = theta_end - sector_degree;
         theta_tmp = theta_start;

         theta_discrete_deg = (theta_start + theta_end)/2;
         theta_discrete_rad = theta_discrete_deg *(pi/180);          
                           
         %Looping through the borders
         for j = 1:length(sector_radius)-1
             
             %Need to restart this after each j-iteration. Look at line
             %167.
             theta_start = theta_end - sector_degree;
             
             %The local borders in each sector.
             x_loc_start = sector_radius(j);
             x_loc_end = sector_radius(j+1);        
                   
             %The local x distance in each sector.
             x_local = sqrt((xy_polar_cord_prob(:,1).^2 + xy_polar_cord_prob(:,2).^2))...
                 .* cos(abs(xy_polar_cord_prob(:,4)-theta_discrete_rad));
            
                %To account for negative values in the find_search below.
                if theta_tmp < 0
                                        
                    %Saving the column with the info about the degree to
                    %the coordinate.
                    xy_dir_row_temp = xy_polar_cord_prob(:,5);
                    
                    %Looping through the degree column to change the
                    %largest degrees. This is to make the find function to
                    %work
                    for k = 1:size(xy_polar_cord_prob,1)
                       
                        if xy_polar_cord_prob(k,5) > theta(end)
                           
                            xy_polar_cord_prob(k,5) = xy_polar_cord_prob(k,5) - 360;
                            
                        end
                        
                    end
                    
                    %Rows that match the criteria.
                    res_rows = find(xy_polar_cord_prob(:,5) >= theta_start ...
                                & xy_polar_cord_prob(:,5) < theta_end ...
                                & x_local(:) <= x_loc_end ...
                                & x_local(:) > x_loc_start);
                            
                    %Inserting the original values back again.
                    xy_polar_cord_prob(:,5) = xy_dir_row_temp;
   
                else
                    
                    %Rows that match the criteria.
                    res_rows = find(xy_polar_cord_prob(:,5) >= theta_start ...
                                & xy_polar_cord_prob(:,5) < theta_end ...
                                & x_local(:) <= x_loc_end ...
                                & x_local(:) > x_loc_start);               
                end 
                
                            
                                        
                if ~isempty(res_rows)
                         
                    %To account for negative values in the find_search below.
                    if theta_tmp < 0
                        theta_start = 360 - theta_end;
                    end

                     
                     %Looking if it is close to the origin.
                     if x_loc_end <= sector_radius(2)
                         
                        xy_row = 1;
                        
                     %If the point is at any other place.   
                     else
                         
                         %This if statement is important for finding the
                         %exact row. Small numerical differences can be
                         %crucial...
                         if x_loc_end == sector_radius(end)
                             
                             %The delta_radius/20 will help the
                             %FIND-function to find only one xy_row.
                             xy_row = find(xy_counted_in_sectors(:,3) > (x_loc_start + delta_radius/20) ...
                                     & xy_counted_in_sectors(:,4) == theta_start ...
                                     & xy_counted_in_sectors(:,5) == theta_end);
                                        
                                     if_sentece = 1;
                                    
                                 
                         else
                             xy_row = find(xy_counted_in_sectors(:,3) > (x_loc_start + delta_radius/20) ...
                                     & xy_counted_in_sectors(:,3) < (x_loc_end + delta_radius/20)  ...
                                     & xy_counted_in_sectors(:,4) == theta_start ...
                                     & xy_counted_in_sectors(:,5) == theta_end);  
                                 
                                     if_sentece = 2;                                                            
                                                                                       
                         end
                         
                         %This is useful for checking where the error is if
                         %the FIND-function finds more than one xy_row.
                         if length(xy_row) > 1
                             
                             fprintf('\nTime no: %i\n',xy_counter);
                             fprintf('Rows found: %i\n',xy_row');
                             fprintf('Sector no: %i\n',i);
                             fprintf('Radius no: %i\n',j);
                             fprintf('If_sentence no: %i\n',if_sentece);
                             fprintf('theta_start: %f\n',theta_start);
                             fprintf('theta_end: %f\n',theta_end);
                             fprintf('x_loc_start: %f\n',x_loc_start);
                             fprintf('x_loc_end + delta_radius/2: %f\n',(x_loc_start + delta_radius/20));
                             fprintf('x_loc_end: %f\n',x_loc_end);
                             fprintf('x_loc_end + delta_radius/2: %f\n',(x_loc_end + delta_radius/20));
                            
                             xy_counter = xy_counter + 1;                             
                             
                         end
                                          
                     end
                     
                     %This if-sentence shows where the error is the xy_row
                     %is empty.
                     if isempty(xy_row)
                        
                         fprintf('\nx: %f\n',xy_polar_cord_prob(res_rows,1));
                         fprintf('y: %f\n',xy_polar_cord_prob(res_rows,2));
                         fprintf('x_loc_start: %f\n',x_loc_start);
                         fprintf('x_loc_end: %f\n',x_loc_end);
                         fprintf('theta_start: %f\n',theta_start);
                         fprintf('theta_end: %f\n\n',theta_end);
                         
                     end
                                
                     %The for-loop inserts the counts and the prob. at the
                     %discrete points.
                     for k = 1:length(res_rows)
                        
                        %The counts.
                        xy_counted_in_sectors(xy_row,6) = xy_counted_in_sectors(xy_row,6) + xy_polar_cord_prob(res_rows(k),6);
                        
                        %The probability.
                        xy_counted_in_sectors(xy_row,7) = xy_counted_in_sectors(xy_row,7) + xy_polar_cord_prob(res_rows(k),7);
                         
                         
                     end

                end                 
                                                    
         end       
        
    end

%Some key numbers.
fprintf('\nsum_cord_count = %i\n',sum(xy_polar_cord_prob(:,6)));
fprintf('sum_xy_sector_count = %i\n',sum(xy_counted_in_sectors(:,6)));
fprintf('Diff in count: %i\n',abs(sum(xy_counted_in_sectors(:,6)) - sum(xy_polar_cord_prob(:,6))));
fprintf('Sum_orig_prob = %f\n',sum(xy_polar_cord_prob(:,7)));
fprintf('Sum_counted_prob = %f\n',sum(xy_counted_in_sectors(:,7)));
fprintf('Diff in prob: %f\n',abs(sum(xy_counted_in_sectors(:,7)) - sum(xy_polar_cord_prob(:,7))));

end

