function A = postprocess_mpf(filename)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%postproccesor.m
%
%The scripts imports the results from a .mpf file created by
%RIFLEX,VIVANA and etc. It creates a struct with the data from the mpf file
%and plots the results in a folder.
%
%ReadMPF.m is the function that is used for reading the .mpf file.
%
%Created by: Emir Lejlic
%Date:       28.02.2013
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Starts the timer
tic;

%The variable A will be a struct with all of the information in the .mpf
%file.

A = ReadMPF(filename);

%This is needed in order to distinguish between vivana and stamod e.g.
underline_start = strfind(filename,'_');
dot_start = strfind(filename,'.');

%this will give the folder name stamod or vivana.
fig_fold_name = strcat(filename(underline_start+1:dot_start-1),'_mpf_plots'); 

%Size info of the result for the for-loop.
[~, A_col] = size(A);

%This function checks if the figure folder exist in current directory. 
%If not, it will create one. Check exist on the internet for more info.
if exist(fig_fold_name,'dir') ~= 7 
    mkdir(fig_fold_name);
end


%figures path
fig_path = fullfile(cd,fig_fold_name);

fprintf('\n');
fprintf('******************************\n');
fprintf('Creating .png files:\n');
fprintf('******************************\n\n');

    for i = 1:A_col

        x_values = A(1,i).values(:,1);
        y_values = A(1,i).values(:,2:end);
        
        [y_val_row, ~] = size(y_values);
        
        %Some of the MATRIXES in the .mpf-file are small, and therefore the
        %interval_jumper has to be small in order to create a plot.
        
            if y_val_row > 1000
                
                interval_jumper = 10;
                
            else
                
                interval_jumper = 1;                 
            
            end

        %leg_col has info on how many legends there are. 
        [~, leg_col] = size(A(1,i).legend);

            for j = 1:leg_col-1
                legend_name(j) = A(1,i).legend(j+1);
            end

            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %                             PLOTTING                        %
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

            %title, xlabel and ylabel
            title_name = A(1,i).name;
            x_name = A(1,i).xlabel;
            y_name = A(1,i).ylabel;
            fig_name = A(1,i).title;

            %The plotting and saving as .png files.
            figure()
            grid on;
            set(gcf,'Visible','off') %Turns current figure off.
            plot(x_values(1:interval_jumper:end),y_values(1:interval_jumper:end,:));
            legend(legend_name,'Location','EastOutside');
            title(title_name);
            xlabel(x_name);
            ylabel(y_name);
           
            
            %This is the way I can create my figures 
            export_fig(fullfile(fig_path,fig_name),'-pdf','-transparent','-painters');            

            copyfile(name_pdf,copy_to_folder);
            delete(name_pdf);
            clear name name_eps name_pdf;
            %Saves the plot results as .png in the result_path: 
            saveas(gcf,fullfile(fig_path,fig_name),'png')
            
            fprintf('%i: %s\n',i,title_name);

            %Clearing the variable names for the new plots.
            clear legend_name;
            clear title_name;
            clear x_name;
            clear y_name;
            clear png_title;

            close all
    end
    
    

%Showes the time used in one analysis.
Elapsed_time = toc;
fprintf('\n');
fprintf('******************************\n');
fprintf('The postprocessing is finished\n');
fprintf('Elapsed time: %5.2f s\n',Elapsed_time);
fprintf('******************************\n');

exit;

end

