@ECHO Off
SETLOCAL ENABLEDELAYEDEXPANSION


rem ** PATHS
SET SIMDIR=%CD%
SET RIFLEX_HOME=C:\Users\lejlic\master_thesis\riflex_simo_academic_4.0.2\Riflex\bin
SET INP=%SIMDIR%\input
SET MATROOT=C:\programs\MATLAB\R2012a\bin
SET MAT_SCRIPTS=%SIMDIR%\mat


REM ** CONTROL WHICH RESULTS FILES THAT WILL BE DELETED
SET CLEAN=*.ffi *.sam *.gnd *.raf *.plt *.plo *.t *.ts *.key
SET CLEAN_MATLAB=*.m

rem ** CONTROL STAMOD AND DYNMOD MEMORY
SET RIFLEX_STAMOD_MEM=800
SET RIFLEX_DYNMOD_MEM=800
SET RIFLEX_MAXDYN_IFNDYN=800000

rem ** PROMPT SYSTEM IDENTIFIER
SET /P SYSID="Please enter system identifier (ID):"
SET /P CASES="Please enter case list file:"
SET RINP=%SYSID%_inpmod.inp
SET RSTA=%SYSID%_stamod.inp
SET RVIV=%SYSID%_vivana.inp
SET FATDAM=fatigue_damage.txt

rem ** LOOP CASES
FOR /F "eol=# tokens=1,2,3,4,5,6,7,8" %%a IN (%CASES%) DO (
  
    rem ** Assign case variables
    SET RUNID=%%a
    SET CURDIR=%%b
    SET XPOS=%%c        
    SET YPOS=%%d
    SET PROB=%%e 
    SET XNAME=%%f
    SET YNAME=%%g
    SET PROBNAME=%%h
    
    rem ** Create result folders
    TITLE Analysis running - !RUNID!
    SET RESDIR=%SIMDIR%\results\%SYSID%\!RUNID!_xpos!XNAME!ypos!YNAME!prob!PROBNAME!
    IF NOT EXIST !RESDIR! (MD !RESDIR!) 
    CD !RESDIR!
    
    rem ** Copy master input files (remember that in your case *_inpmod.inp also contain the RAOs)
    COPY %INP%\%SYSID%_*.inp . /Y
    
    rem ** copying the matlab scripts to the result map in order to run the script from there.
    COPY %MAT_SCRIPTS%\*.m . /Y
    
    rem ** Inserting values for wildcards in inpmod.inp
    CALL %MATROOT%\matlab -nodesktop -nosplash -wait -nojvm -r "change_str_in_file !RESDIR!\%SYSID%_inpmod.inp $CURDIR !CURDIR! $XPOS !XPOS! $YPOS !YPOS!"
    
    rem ** Riflex (INPMOD, STAMOD, VIVANA)     
    FOR %%z IN ( i s v ) DO (CALL %RIFLEX_HOME%\riflex %%z %SYSID%)
    
    rem ** Clean
    DEL %CLEAN%
    
    rem ** Plotting VIVANA results from the mpf file:
    rem ** FOR %%z IN ( stamod vivana ) DO (CALL %MATROOT%\matlab -nodesktop -wait -nosplash -nojvm -r "postprocess_mpf %SYSID%_%%z.mpf"  )    
    
    rem ** Extracting the fatigue damage from the .mpf file and deletning and creating
    rem ** a new .txt file containing the fatigue results in order to take up less space.        
    CALL %MATROOT%\matlab -nodesktop -nosplash -wait -nojvm -r "extract_fatigue_from_mpf %SYSID%_vivana.mpf %FATDAM%"
         
    DEL %CLEAN_MATLAB%
    rem ** Deleting the .mpf files which take up a lot of space...
    DEL *.mpf
    
    CD %SIMDIR%
  )
  
rem ** CREATE LOG-FILE

ECHO #Status of analyses > run_log.log

rem ** > creates a new run.log, while >> adds text to an existing run.log file

FOR /F "eol=# tokens=1,2,3,4,5,6,7,8" %%a IN (%CASES%) DO ( 

rem ** Assign case variables

SET RUNID=%%a
SET CURDIR=%%b
SET XPOS=%%c        
SET YPOS=%%d
SET PROB=%%e 
SET XNAME=%%f
SET YNAME=%%g
SET PROBNAME=%%h
    

    SET RESDIR=%SIMDIR%\results\%SYSID%\!RUNID!_xpos!XNAME!ypos!YNAME!prob!PROBNAME!
    SET FATIGUE_FILE=!RESDIR!\fatigue_damage.txt       

    IF NOT EXIST !RESDIR! (

        ECHO !RUNID! not existing >> run_log.log

    ) ELSE (

        FOR %%f IN (!FATIGUE_FILE! ) DO (
        
            SET FILESIZE=%%~zf
        
            rem ** the number represents the size of .mpf in bytes. (1 kb = 111 bytes)
            IF !FILESIZE! GEQ 1000 (

                ECHO !RUNID! completed. >> run_log.log
                 

            ) ELSE (

                ECHO !RUNID! failed. >> run_log.log

            )

        )   

    )

  )
  
TITLE %CASES% COMPLETE
PAUSE